@@ -1,18 +1,19 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2023, by Thomas Morgan.
 
-require 'protocol/http/request'
-require 'protocol/http/headers'
-require 'protocol/websocket/headers'
-require 'protocol/http/body/readable'
+require "protocol/http/request"
+require "protocol/http/headers"
+require "protocol/websocket/headers"
+require "protocol/http/body/readable"
 
-require 'async/variable'
+require "async/variable"
 
 module Async
 	module WebSocket
-		# This is required for HTTP/1.x to upgrade the connection to the WebSocket protocol.
+		# This is required for HTTP/2 to establish a connection using the WebSocket protocol.
 		# See https://tools.ietf.org/html/rfc8441 for more details.
 		class ConnectRequest < ::Protocol::HTTP::Request
 			include ::Protocol::WebSocket::Headers
@@ -27,6 +28,10 @@ module Async
 					@response.close
 				end
 				
+				def unwrap
+					@response.buffered!
+				end
+				
 				attr_accessor :response
 				attr_accessor :stream
 				
@@ -70,7 +75,7 @@ module Async
 				headers.add(SEC_WEBSOCKET_VERSION, String(version))
 				
 				if protocols.any?
-					headers.add(SEC_WEBSOCKET_PROTOCOL, protocols.join(','))
+					headers.add(SEC_WEBSOCKET_PROTOCOL, protocols.join(","))
 				end
 				
 				super(request.scheme, request.authority, ::Protocol::HTTP::Methods::CONNECT, request.path, nil, headers, body, PROTOCOL)
