@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'connect_request'
-require_relative 'upgrade_request'
-require_relative 'error'
+require_relative "connect_request"
+require_relative "upgrade_request"
+require_relative "error"
 
 module Async
 	module WebSocket
