@@ -1,12 +1,12 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'upgrade_response'
-require_relative 'connect_response'
+require_relative "upgrade_response"
+require_relative "connect_response"
 
-require_relative 'error'
+require_relative "error"
 
 module Async
 	module WebSocket
