@@ -1,38 +1,44 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2023, by Thomas Morgan.
+# Copyright, 2024, by Ryu Sato.
 
-require 'protocol/http/middleware'
-require 'protocol/http/request'
+require "protocol/http/middleware"
+require "protocol/http/request"
 
-require 'protocol/http/headers'
-require 'protocol/websocket/headers'
+require "protocol/http/headers"
+require "protocol/websocket/headers"
 
-require 'securerandom'
-
-require_relative 'error'
+require_relative "error"
 
 module Async
 	module WebSocket
 		# This is required for HTTP/1.x to upgrade the connection to the WebSocket protocol.
+		# See https://tools.ietf.org/html/rfc6455
 		class UpgradeRequest < ::Protocol::HTTP::Request
 			include ::Protocol::WebSocket::Headers
 			
 			class Wrapper
-				def initialize(response)
+				def initialize(response, verified:)
 					@response = response
 					@stream = nil
+					@verified = verified
 				end
 				
 				def close
 					@response.close
 				end
 				
+				def unwrap
+					@response.buffered!
+				end
+				
 				attr_accessor :response
 				
 				def stream?
-					@response.status == 101
+					@response.status == 101 && @verified
 				end
 				
 				def status
@@ -57,7 +63,7 @@ module Async
 				headers.add(SEC_WEBSOCKET_VERSION, String(version))
 				
 				if protocols.any?
-					headers.add(SEC_WEBSOCKET_PROTOCOL, protocols.join(','))
+					headers.add(SEC_WEBSOCKET_PROTOCOL, protocols.join(","))
 				end
 				
 				super(request.scheme, request.authority, ::Protocol::HTTP::Methods::GET, request.path, nil, headers, nil, PROTOCOL)
@@ -74,7 +80,9 @@ module Async
 					end
 				end
 				
-				return Wrapper.new(response)
+				verified = accept_digest && Array(response.protocol).map(&:downcase) == %w(websocket) && response.headers["connection"]&.include?("upgrade")
+				
+				return Wrapper.new(response, verified: verified)
 			end
 		end
 	end
