@@ -1,11 +1,12 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2023, by Thomas Morgan.
 
-require 'async/http/body/hijack'
-require 'protocol/http/response'
-require 'protocol/websocket/headers'
+require "async/http/body/hijack"
+require "protocol/http/response"
+require "protocol/websocket/headers"
 
 module Async
 	module WebSocket
@@ -18,7 +19,6 @@ module Async
 				
 				if accept_nounce = request.headers[SEC_WEBSOCKET_KEY]&.first
 					headers.add(SEC_WEBSOCKET_ACCEPT, Nounce.accept_digest(accept_nounce))
-					status = 101
 					
 					if protocol
 						headers.add(SEC_WEBSOCKET_PROTOCOL, protocol)
